<?php
namespace wcf\system\template\plugin;
use wcf\system\exception\SystemException;
use wcf\system\template\TemplateScriptingCompiler;

/**
 * Template compiler plugin which fetches and compiles php files from the local file system and displays the content or saves it in a template var. The path is relative to the WCF_DIR.
 * 
 * Usage:
 * 	{includePHP file='x.php'}
 * 	{includePHP file='x.php' assign=var}
 * 
 * @author	Christopher Walz
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 */
class IncludePHPCompilerTemplatePlugin implements ICompilerTemplatePlugin {
	/**
	 * @inheritDoc
	 */
	public function executeStart($tagArgs, TemplateScriptingCompiler $compiler) {
		if (!isset($tagArgs['file'])) {
			throw new SystemException($compiler::formatSyntaxError("missing 'file' argument in includePHP tag", $compiler->getCurrentIdentifier(), $compiler->getCurrentLineNo()));
		}
		
		$tagArgs['file'] = str_replace(['"', "'"], ['', ''], $tagArgs['file']);
		
		if (isset($tagArgs['assign'])) {
			$phpCode = 'ob_start(); @include("' . WCF_DIR . $tagArgs["file"] . '");$content = ob_get_contents();ob_end_clean();';
			return "<?php $phpCode \$this->assign(".$tagArgs['assign'].", \$content); ?>";
			
		}
		else {
			$phpCode = 'ob_start(); @include("' . WCF_DIR . $tagArgs["file"] . '");ob_end_flush();';
			return "<?php echo $phpCode ?>";
		}
	}
	
	/**
	 * @inheritDoc
	 */
	public function executeEnd(TemplateScriptingCompiler $compiler) {
		throw new SystemException($compiler::formatSyntaxError("unknown tag {/includePHP}", $compiler->getCurrentIdentifier(), $compiler->getCurrentLineNo()));
	}
}
